@@ -10,6 +10,7 @@ MYPKGOPTIONS <- settings::options_manager(
   colname_for_value = "value",
   colname_for_blocks = "block_name___",
   colname_for_order = "order___",
+  colname_for_variable_compact = " ",
   labels_TRUE_FALSE = c("yes", "no"),
   labels_Mean_SD = "Mean (SD)",
   labels_valid_missing = "valid (missing)",
@@ -69,9 +70,122 @@ MYPKGOPTIONS <- settings::options_manager(
   indent_character_Latex = "\\quad",
   indent_character_HTML = " &emsp; ",
   indent_character_Console = "    ",
-  indent_character_markdown = "&nbsp;&nbsp;&nbsp;&nbsp;"
+  indent_character_markdown = "&nbsp;&nbsp;&nbsp;&nbsp;",
+  indent_character_compact = "   ",
+  indent = TRUE,
+
+  format_statistics_compact.statistics_factor = function(x, ...)
+  {
+
+    nn <- names(x)
+
+    value <- unlist(x)
+    total <- sum(value)
 
 
+    percent <- 100 * value/total
+
+    if(length(nn)<=3){
+      # return only first level, ignore the others
+      # As atable::statistics.factor calls table(..., useNA='always'), there is always NA in nn and thus three
+      # levels are the minimum, not two levels
+      # The counts of missing values will not be displayed, but are included in the percent-calculation in the denominator
+
+      value <- paste0(atable_options("format_percent")(percent[1]), "% (", atable_options("format_numbers")(value[1]), ")")
+
+
+      format_statistics_out <- data.frame(tag = factor(nn[1], levels = nn[1]), value = value[1],
+                                          row.names = NULL, stringsAsFactors = FALSE, check.names = FALSE, fix.empty.names = FALSE)
+
+      return(format_statistics_out)
+    }  else{
+
+
+      value <- paste0(atable_options("format_percent")(percent), "% (", atable_options("format_numbers")(value), ")")
+
+
+
+      format_statistics_out <- data.frame(tag = factor(nn, levels = nn),
+                                          value = value,
+                                          row.names = NULL, stringsAsFactors = FALSE, check.names = FALSE, fix.empty.names = FALSE)
+
+      return(format_statistics_out)
+    }
+  },
+
+  format_statistics_compact.statistics_numeric = function(x, ...)
+  {
+
+    the_mean <- atable_options("format_numbers")(x$mean)
+    the_sd <- atable_options("format_numbers")(x$sd)
+
+    values <- c(Mean_SD = paste0(the_mean, " (", the_sd, ")") )
+
+    format_statistics_out <- data.frame(tag = factor("remove_me", levels = "remove_me"),
+                                        value = values, row.names = NULL, stringsAsFactors = FALSE, check.names = FALSE,
+                                        fix.empty.names = FALSE)
+
+    return(format_statistics_out)
+
+  },
+
+  format_statistics_longitudinal.statistics_factor = function(x, ...)
+  {
+
+    nn <- names(x)
+
+    value <- unlist(x)
+    total <- sum(value)
+
+
+    percent <- 100 * value/total
+
+    if(length(nn)<=3){
+      # return only first level, ignore the others
+      # As atable::statistics.factor calls table(..., useNA='always'), there is always NA in nn and thus three
+      # levels are the minimum, not two levels
+      # The counts of missing values will not be displayed, but are included in the percent-calculation in the denominator
+      # Add total number of observations
+
+      value <- paste0(atable_options("format_percent")(percent[1]), "% (", atable_options("format_numbers")(value[1]), " / ", atable_options("format_numbers")(total), ")")
+
+
+      format_statistics_out <- data.frame(tag = factor(nn[1], levels = nn[1]), value = value[1],
+                                          row.names = NULL, stringsAsFactors = FALSE, check.names = FALSE, fix.empty.names = FALSE)
+
+      return(format_statistics_out)
+    }  else{
+
+
+      value <- paste0(atable_options("format_percent")(percent), "% (", atable_options("format_numbers")(value), ")")
+
+
+
+      format_statistics_out <- data.frame(tag = factor(nn, levels = nn),
+                                          value = value,
+                                          row.names = NULL, stringsAsFactors = FALSE, check.names = FALSE, fix.empty.names = FALSE)
+
+      return(format_statistics_out)
+    }
+  },
+
+  format_statistics_longitudinal.statistics_numeric = function(x, ...)
+  {
+
+    the_mean <- atable_options("format_numbers")(x$mean)
+    the_sd <- atable_options("format_numbers")(x$sd)
+    the_valids = x$length - x$missing
+    the_missing = x$missing
+
+    values <- c(Mean_SD = paste0(the_mean, " (", the_sd, "), ",the_valids, ", ", the_missing) )
+
+    format_statistics_out <- data.frame(tag = factor("mean_sd_valid_missing", levels = "mean_sd_valid_missing"),
+                                        value = values, row.names = NULL, stringsAsFactors = FALSE, check.names = FALSE,
+                                        fix.empty.names = FALSE)
+
+    return(format_statistics_out)
+
+  }
 )
 # User function that gets exported:
 #' Set or get options
@@ -136,6 +250,9 @@ MYPKGOPTIONS <- settings::options_manager(
 #'   This character shows up in the results of \code{\link{atable}} when \code{group_col} is \code{NULL}.
 #'   The column will contain the results of the \code{\link{statistics}}.}
 #'
+#'   \item{\code{colname_for_variable_compact}}{: A character of length 1. Default is \code{intToUtf8(160)}, a non-breaking space.
+#'   This character will show up in the results of \code{\link{atable_compact}} as name of the first column.}
+#'
 #'   \item{\code{statistics.numeric}}{: Either \code{NULL} or a function. Default is \code{NULL}.
 #'   If a function, then it will replace \code{atable:::statistics.numeric} when atable is called.
 #'   The function must mimic \code{\link{statistics}}: see the help there.}
@@ -202,6 +319,23 @@ MYPKGOPTIONS <- settings::options_manager(
 #'
 #'    \item{\code{indent_character}}{: A Character with length 1. Passed to \code{indent_data_frame}. Every option of \code{format_to}
 #'    has a corresponding indent_character. See the help of \code{atable} for these options. }
+#'
+#'    \item{\code{indent_character_compact}}{: A Character with length 1. Passed to \code{atable_compact}.
+#'    Value is \code{"   "} for viewing in the console. Use \code{"\\quad"} for Latex and \code{intToUtf8(160)} for Word.}
+#'
+#'   \item{\code{indent}}{: A logical with length 1. Passed to \code{atable}. Controls, if indent_data_frame is called.}
+#'
+#'    \item{\code{format_statistics_compact.statistics_factor}}{: A function with the same Properties as \code{\link{format_statistics}}. Used as a
+#'    default value for \code{\link{atable_compact}}}
+#'
+#'    \item{\code{format_statistics_compact.statistics_numeric }}{: A function with the same Properties as \code{\link{format_statistics}}. Used as a
+#'    default value for \code{\link{atable_compact}}}
+#'
+#'    \item{\code{format_statistics_longitudinal.statistics_factor}}{: A function with the same Properties as \code{\link{format_statistics}}. Used as a
+#'    default value for \code{\link{atable_longitudinal}}}
+#'
+#'    \item{\code{format_statistics_longitudinal.statistics_numeric }}{: A function with the same Properties as \code{\link{format_statistics}}. Used as a
+#'    default value for \code{\link{atable_longitudinal}}}
 #' }
 #'
 #' @examples
